nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

LowpwrCtrl

Struct LowpwrCtrl 

#[repr(transparent)]
pub struct LowpwrCtrl(pub u32);
XTAL OSC (LP) Control Register

Tuple Fields

0: u32

Implementations

Source

impl LowpwrCtrl

pub const fn rc_osc_en(&self) -> LowpwrCtrlRcOscEn

RC Osc. enable control.

pub const fn set_rc_osc_en(&mut self, val: LowpwrCtrlRcOscEn)

RC Osc. enable control.

pub const fn osc_sel(&self) -> LowpwrCtrlOscSel

Select the source for the 24MHz clock.

pub const fn set_osc_sel(&mut self, val: LowpwrCtrlOscSel)

Select the source for the 24MHz clock.

pub const fn lpbg_sel(&self) -> LowpwrCtrlLpbgSel

Bandgap select. Not related to oscillator.

pub const fn set_lpbg_sel(&mut self, val: LowpwrCtrlLpbgSel)

Bandgap select. Not related to oscillator.

pub const fn lpbg_test(&self) -> bool

Low power bandgap test bit. Not related to oscillator.

pub const fn set_lpbg_test(&mut self, val: bool)

Low power bandgap test bit. Not related to oscillator.

pub const fn reftop_ibias_off(&self) -> bool

Low power reftop ibias disable. Not related to oscillator.

pub const fn set_reftop_ibias_off(&mut self, val: bool)

Low power reftop ibias disable. Not related to oscillator.

pub const fn l1_pwrgate(&self) -> bool

L1 power gate control. Used as software override. Not related to oscillator.

pub const fn set_l1_pwrgate(&mut self, val: bool)

L1 power gate control. Used as software override. Not related to oscillator.

pub const fn l2_pwrgate(&self) -> bool

L2 power gate control. Used as software override. Not related to oscillator.

pub const fn set_l2_pwrgate(&mut self, val: bool)

L2 power gate control. Used as software override. Not related to oscillator.

pub const fn cpu_pwrgate(&self) -> bool

CPU power gate control. Used as software override. Test purpose only Not related to oscillator.

pub const fn set_cpu_pwrgate(&mut self, val: bool)

CPU power gate control. Used as software override. Test purpose only Not related to oscillator.

pub const fn display_pwrgate(&self) -> bool

Display logic power gate control. Used as software override. Not related to oscillator.

pub const fn set_display_pwrgate(&mut self, val: bool)

Display logic power gate control. Used as software override. Not related to oscillator.

pub const fn rcosc_cg_override(&self) -> bool

For debug purposes only

pub const fn set_rcosc_cg_override(&mut self, val: bool)

For debug purposes only

pub const fn xtalosc_pwrup_delay(&self) -> LowpwrCtrlXtaloscPwrupDelay

Specifies the time delay between when the 24MHz xtal is powered up until it is stable and ready to use

pub const fn set_xtalosc_pwrup_delay( &mut self, val: LowpwrCtrlXtaloscPwrupDelay, )

Specifies the time delay between when the 24MHz xtal is powered up until it is stable and ready to use

pub const fn xtalosc_pwrup_stat(&self) -> LowpwrCtrlXtaloscPwrupStat

Status of the 24MHz xtal oscillator.

pub const fn set_xtalosc_pwrup_stat(&mut self, val: LowpwrCtrlXtaloscPwrupStat)

Status of the 24MHz xtal oscillator.

pub const fn mix_pwrgate(&self) -> bool

Display power gate control. Used as software mask. Set to zero to force ungated.

pub const fn set_mix_pwrgate(&mut self, val: bool)

Display power gate control. Used as software mask. Set to zero to force ungated.

pub const fn gpu_pwrgate(&self) -> bool

GPU power gate control. Used as software mask. Set to zero to force ungated.

pub const fn set_gpu_pwrgate(&mut self, val: bool)

GPU power gate control. Used as software mask. Set to zero to force ungated.