#[repr(transparent)]pub struct LowpwrCtrlSet(pub u32);Expand description
XTAL OSC (LP) Control Register
Tuple Fields
0: u32Implementations
Sourceimpl LowpwrCtrlSet
impl LowpwrCtrlSet
Sourcepub const fn rc_osc_en(&self) -> LowpwrCtrlSetRcOscEn
pub const fn rc_osc_en(&self) -> LowpwrCtrlSetRcOscEn
RC Osc. enable control.
Sourcepub const fn set_rc_osc_en(&mut self, val: LowpwrCtrlSetRcOscEn)
pub const fn set_rc_osc_en(&mut self, val: LowpwrCtrlSetRcOscEn)
RC Osc. enable control.
Sourcepub const fn osc_sel(&self) -> LowpwrCtrlSetOscSel
pub const fn osc_sel(&self) -> LowpwrCtrlSetOscSel
Select the source for the 24MHz clock.
Sourcepub const fn set_osc_sel(&mut self, val: LowpwrCtrlSetOscSel)
pub const fn set_osc_sel(&mut self, val: LowpwrCtrlSetOscSel)
Select the source for the 24MHz clock.
Sourcepub const fn lpbg_sel(&self) -> LowpwrCtrlSetLpbgSel
pub const fn lpbg_sel(&self) -> LowpwrCtrlSetLpbgSel
Bandgap select. Not related to oscillator.
Sourcepub const fn set_lpbg_sel(&mut self, val: LowpwrCtrlSetLpbgSel)
pub const fn set_lpbg_sel(&mut self, val: LowpwrCtrlSetLpbgSel)
Bandgap select. Not related to oscillator.
Sourcepub const fn set_lpbg_test(&mut self, val: bool)
pub const fn set_lpbg_test(&mut self, val: bool)
Low power bandgap test bit. Not related to oscillator.
Sourcepub const fn reftop_ibias_off(&self) -> bool
pub const fn reftop_ibias_off(&self) -> bool
Low power reftop ibias disable. Not related to oscillator.
Sourcepub const fn set_reftop_ibias_off(&mut self, val: bool)
pub const fn set_reftop_ibias_off(&mut self, val: bool)
Low power reftop ibias disable. Not related to oscillator.
Sourcepub const fn l1_pwrgate(&self) -> bool
pub const fn l1_pwrgate(&self) -> bool
L1 power gate control. Used as software override. Not related to oscillator.
Sourcepub const fn set_l1_pwrgate(&mut self, val: bool)
pub const fn set_l1_pwrgate(&mut self, val: bool)
L1 power gate control. Used as software override. Not related to oscillator.
Sourcepub const fn l2_pwrgate(&self) -> bool
pub const fn l2_pwrgate(&self) -> bool
L2 power gate control. Used as software override. Not related to oscillator.
Sourcepub const fn set_l2_pwrgate(&mut self, val: bool)
pub const fn set_l2_pwrgate(&mut self, val: bool)
L2 power gate control. Used as software override. Not related to oscillator.
Sourcepub const fn cpu_pwrgate(&self) -> bool
pub const fn cpu_pwrgate(&self) -> bool
CPU power gate control. Used as software override. Test purpose only Not related to oscillator.
Sourcepub const fn set_cpu_pwrgate(&mut self, val: bool)
pub const fn set_cpu_pwrgate(&mut self, val: bool)
CPU power gate control. Used as software override. Test purpose only Not related to oscillator.
Sourcepub const fn display_pwrgate(&self) -> bool
pub const fn display_pwrgate(&self) -> bool
Display logic power gate control. Used as software override. Not related to oscillator.
Sourcepub const fn set_display_pwrgate(&mut self, val: bool)
pub const fn set_display_pwrgate(&mut self, val: bool)
Display logic power gate control. Used as software override. Not related to oscillator.
Sourcepub const fn rcosc_cg_override(&self) -> bool
pub const fn rcosc_cg_override(&self) -> bool
For debug purposes only
Sourcepub const fn set_rcosc_cg_override(&mut self, val: bool)
pub const fn set_rcosc_cg_override(&mut self, val: bool)
For debug purposes only
Sourcepub const fn xtalosc_pwrup_delay(&self) -> LowpwrCtrlSetXtaloscPwrupDelay
pub const fn xtalosc_pwrup_delay(&self) -> LowpwrCtrlSetXtaloscPwrupDelay
Specifies the time delay between when the 24MHz xtal is powered up until it is stable and ready to use
Sourcepub const fn set_xtalosc_pwrup_delay(
&mut self,
val: LowpwrCtrlSetXtaloscPwrupDelay,
)
pub const fn set_xtalosc_pwrup_delay( &mut self, val: LowpwrCtrlSetXtaloscPwrupDelay, )
Specifies the time delay between when the 24MHz xtal is powered up until it is stable and ready to use
Sourcepub const fn xtalosc_pwrup_stat(&self) -> LowpwrCtrlSetXtaloscPwrupStat
pub const fn xtalosc_pwrup_stat(&self) -> LowpwrCtrlSetXtaloscPwrupStat
Status of the 24MHz xtal oscillator.
Sourcepub const fn set_xtalosc_pwrup_stat(
&mut self,
val: LowpwrCtrlSetXtaloscPwrupStat,
)
pub const fn set_xtalosc_pwrup_stat( &mut self, val: LowpwrCtrlSetXtaloscPwrupStat, )
Status of the 24MHz xtal oscillator.
Sourcepub const fn mix_pwrgate(&self) -> bool
pub const fn mix_pwrgate(&self) -> bool
Display power gate control. Used as software mask. Set to zero to force ungated.
Sourcepub const fn set_mix_pwrgate(&mut self, val: bool)
pub const fn set_mix_pwrgate(&mut self, val: bool)
Display power gate control. Used as software mask. Set to zero to force ungated.
Sourcepub const fn gpu_pwrgate(&self) -> bool
pub const fn gpu_pwrgate(&self) -> bool
GPU power gate control. Used as software mask. Set to zero to force ungated.
Sourcepub const fn set_gpu_pwrgate(&mut self, val: bool)
pub const fn set_gpu_pwrgate(&mut self, val: bool)
GPU power gate control. Used as software mask. Set to zero to force ungated.