#[repr(transparent)]pub struct OscConfig0Tog(pub u32);Expand description
XTAL OSC Configuration 0 Register
Tuple Fields
0: u32Implementations
Sourceimpl OscConfig0Tog
impl OscConfig0Tog
Sourcepub const fn start(&self) -> bool
pub const fn start(&self) -> bool
Start/stop bit for the RC tuning calculation logic. If stopped the tuning logic is reset.
Sourcepub const fn set_start(&mut self, val: bool)
pub const fn set_start(&mut self, val: bool)
Start/stop bit for the RC tuning calculation logic. If stopped the tuning logic is reset.
Sourcepub const fn set_enable(&mut self, val: bool)
pub const fn set_enable(&mut self, val: bool)
Enables the tuning logic to calculate new RC tuning values
Sourcepub const fn bypass(&self) -> bool
pub const fn bypass(&self) -> bool
Bypasses any calculated RC tuning value and uses the programmed register value.
Sourcepub const fn set_bypass(&mut self, val: bool)
pub const fn set_bypass(&mut self, val: bool)
Bypasses any calculated RC tuning value and uses the programmed register value.
Sourcepub const fn set_invert(&mut self, val: bool)
pub const fn set_invert(&mut self, val: bool)
Invert the stepping of the calculated RC tuning value.
Sourcepub const fn rc_osc_prog(&self) -> u8
pub const fn rc_osc_prog(&self) -> u8
RC osc. tuning values.
Sourcepub const fn set_rc_osc_prog(&mut self, val: u8)
pub const fn set_rc_osc_prog(&mut self, val: u8)
RC osc. tuning values.
Sourcepub const fn set_hyst_plus(&mut self, val: u8)
pub const fn set_hyst_plus(&mut self, val: u8)
Positive hysteresis value
Sourcepub const fn hyst_minus(&self) -> u8
pub const fn hyst_minus(&self) -> u8
Negative hysteresis value
Sourcepub const fn set_hyst_minus(&mut self, val: u8)
pub const fn set_hyst_minus(&mut self, val: u8)
Negative hysteresis value
Sourcepub const fn rc_osc_prog_cur(&self) -> u8
pub const fn rc_osc_prog_cur(&self) -> u8
The current tuning value in use.
Sourcepub const fn set_rc_osc_prog_cur(&mut self, val: u8)
pub const fn set_rc_osc_prog_cur(&mut self, val: u8)
The current tuning value in use.